@@ -1,5 +1,5 @@
 package Selenium::Screenshot;
-$Selenium::Screenshot::VERSION = '0.04';
+$Selenium::Screenshot::VERSION = '0.05';
 # ABSTRACT: Compare and contrast Webdriver screenshots in PNG format
 use Moo;
 use Image::Compare;
@@ -129,6 +129,8 @@ has _cmp => (
     }
 );
 
+with 'Selenium::Screenshot::CanPad';
+
 
 sub compare {
     my ($self, $opponent) = @_;
@@ -222,8 +224,18 @@ sub _set_opponent {
     return unless $opponent;
 
     $opponent = $self->_extract_image( $opponent );
+
+    # Before setting this $opponent as our image2, we must ensure that
+    # our $self->png image and this $opponent are the same size.
+    if (! $self->cmp_image_dims( $self->png, $opponent )) {
+        my ($new_png, $new_opp) = $self->coerce_image_size( $self->png, $opponent );
+        $self->_set_png( $new_png );
+        $opponent = $new_opp;
+    }
+
     $opponent = $self->_img_target( $opponent ) if $self->has_target;
     $opponent = $self->_img_exclude( $opponent ) if $self->has_exclude;
+
     $self->_cmp->set_image2( img => $opponent );
 
     return $opponent;
@@ -397,7 +409,7 @@ Selenium::Screenshot - Compare and contrast Webdriver screenshots in PNG format
 
 =head1 VERSION
 
-version 0.04
+version 0.05
 
 =head1 SYNOPSIS
 
